@@ -15,7 +15,6 @@ _RESET_COLOR = colorama.Style.RESET_ALL
 
 
 class Messenger:
-
     def __init__(self, colorize):
         self._colorize = colorize
 
@@ -29,7 +28,7 @@ class Messenger:
             self._air_needed = False
 
     def request_air(self, future_message):
-        if '\n' in future_message:
+        if "\n" in future_message:
             self._air_needed = True
 
     def _produce_and_request_air(self, future_message):
@@ -39,28 +38,28 @@ class Messenger:
     def tell_info(self, message):
         self._produce_and_request_air(message)
         if self._colorize:
-            message = f'{_INFO_COLOR}{message}{_RESET_COLOR}'
+            message = f"{_INFO_COLOR}{message}{_RESET_COLOR}"
         print(message)
 
     def tell_command(self, argv, comment):
-        self._produce_and_request_air('')
-        epilog = f'  # {comment}' if comment else ''
+        self._produce_and_request_air("")
+        epilog = f"  # {comment}" if comment else ""
         argv = [escape_for_shell_display(arg) for arg in argv]
-        message = f'# {" ".join(argv)}'
+        message = f"# {' '.join(argv)}"
         if self._colorize:
-            message = f'{_COMMAND_COLOR}{message}{_RESET_COLOR}'
+            message = f"{_COMMAND_COLOR}{message}{_RESET_COLOR}"
         message += epilog
 
         print(message, file=sys.stderr)
 
     def tell_error(self, message):
         self._produce_and_request_air(message)
-        message = f'Error: {message}'
+        message = f"Error: {message}"
         if self._colorize:
-            message = f'{_ERROR_COLOR}{message}{_RESET_COLOR}'
+            message = f"{_ERROR_COLOR}{message}{_RESET_COLOR}"
         print(message, file=sys.stderr)
 
     def format_question(self, message):
         if self._colorize:
-            message = f'{_QUESTION_COLOR}{message}{_RESET_COLOR}'
+            message = f"{_QUESTION_COLOR}{message}{_RESET_COLOR}"
         return message
